==> linq-to-typescript-2.0.0.tgz: package/test/tests/SelectAsync.ts <==
import { Enumerable } from "../../src/index"
import { asAsync, itAsync, itEnumerableAsync, itParallel } from "../TestHelpers"

describe("SelectAsync", () => {
    itEnumerableAsync("Basic", async (asEnumerable) => {
        const values = asEnumerable([1, 2, 3, 4, 5, 6, 7, 8, 9])
        const trueValues = values.selectAsync(async (x) => x + 1)
        const asyncValues = await trueValues.toArray()
        expect(await values.select((x) => x + 1).toArray()).toEqual(asyncValues)
    })

    itAsync("From Async", async () => {
        const values = asAsync([1, 2, 3, 4, 5, 6, 7, 8, 9])
        const trueValues = values.selectAsync((x) => new Promise<number>((res) => res(x + 1)))
        const asyncValues = await trueValues.toArray()
        expect(await values.select((x) => x + 1).toArray()).toEqual(asyncValues)
    })

    itParallel("From Parallel", async (asParallel) => {
        const values = asParallel([1, 2, 3, 4, 5, 6, 7, 8, 9])
        const trueValues = values.selectAsync((x) => new Promise<number>((res) => res(x + 1)))
        const asyncValues = await trueValues.toArray()
        expect(await values.select((x) => x + 1).toArray()).toEqual(asyncValues)
    })

    itEnumerableAsync("Basic String Key", async (asEnumerable) => {
        const values = asEnumerable([1, 2, 3])
        const trueValues = values
            .select((x) => {
                return { strKey: (async () => x + 1)() }
            })
            .selectAsync("strKey")
        const asyncValues = await trueValues.toArray()
        expect(await values.select((x) => x + 1).toArray()).toEqual(asyncValues)
    })

    itAsync("From Async String Key", async () => {
        const values = asAsync([1, 2, 3, 4, 5, 6, 7, 8, 9])
        const trueValues = values
            .select((x) => {
                return { strKey: (async () => x + 1)() }
            })
            .selectAsync("strKey")
        const asyncValues = await trueValues.toArray()
        expect(await values.select((x) => x + 1).toArray()).toEqual(asyncValues)
    })

    itParallel("From Parallel String Key", async (asParallel) => {
        const values = asParallel([1, 2, 3, 4, 5, 6, 7, 8, 9])
        const trueValues = values
            .select((x) => {
                return { strKey: (async () => x + 1)() }
            })
            .selectAsync("strKey")
        const asyncValues = await trueValues.toArray()
        expect(await values.select((x) => x + 1).toArray()).toEqual(asyncValues)
    })
})

==> linq-to-typescript-3.1.0.tgz: package/test/tests/SelectAsync.ts <==
import { Enumerable } from "../../src/index"
import { asAsync, itAsync, itEnumerableAsync, itParallel } from "../TestHelpers"

describe("selectAsync", () => {
    itEnumerableAsync("Basic", async (asEnumerable) => {
        const values = asEnumerable([1, 2, 3, 4, 5, 6, 7, 8, 9])
        const trueValues = values.selectAsync(async (x) => x + 1)
        const asyncValues = await trueValues.toArray()
        expect(await values.select((x) => x + 1).toArray()).toEqual(asyncValues)
    })

    itAsync("Basic", async () => {
        const values = asAsync([1, 2, 3, 4, 5, 6, 7, 8, 9])
        const trueValues = values.selectAsync((x) => new Promise<number>((res) => res(x + 1)))
        const asyncValues = await trueValues.toArray()
        expect(await values.select((x) => x + 1).toArray()).toEqual(asyncValues)
    })

    itParallel("Basic", async (asParallel) => {
        const values = asParallel([1, 2, 3, 4, 5, 6, 7, 8, 9])
        const trueValues = values.selectAsync((x) => new Promise<number>((res) => res(x + 1)))
        const asyncValues = await trueValues.toArray()
        expect(await values.select((x) => x + 1).toArray()).toEqual(asyncValues)
    })

    itEnumerableAsync("String Key", async (asEnumerable) => {
        const values = asEnumerable([1, 2, 3])
        const trueValues = values
            .select((x) => {
                return { strKey: (async () => x + 1)() }
            })
            .selectAsync("strKey")
        const asyncValues = await trueValues.toArray()
        expect(await values.select((x) => x + 1).toArray()).toEqual(asyncValues)
    })

    itAsync("String Key", async () => {
        const values = asAsync([1, 2, 3, 4, 5, 6, 7, 8, 9])
        const trueValues = values
            .select((x) => {
                return { strKey: (async () => x + 1)() }
            })
            .selectAsync("strKey")
        const asyncValues = await trueValues.toArray()
        expect(await values.select((x) => x + 1).toArray()).toEqual(asyncValues)
    })

    itParallel("String Key", async (asParallel) => {
        const values = asParallel([1, 2, 3, 4, 5, 6, 7, 8, 9])
        const trueValues = values
            .select((x) => {
                return { strKey: (async () => x + 1)() }
            })
            .selectAsync("strKey")
        const asyncValues = await trueValues.toArray()
        expect(await values.select((x) => x + 1).toArray()).toEqual(asyncValues)
    })
})
